@@ -41,24 +41,22 @@ class SFConfig(SFConfigBase):
     API_PORT: int = Field(13000, description='Port for the REST API')
     API_TIMEOUT: int = Field(
         900,
-        description='How long gunicorn processes can use for a single request',
+        description='How long gunicorn processes can use for a single request'
     )
     API_ASYNC_WAIT: int = Field(
         30,
         description='How long we wait for an async operation to complete '
-                    'before returning to the user',
+                    'before returning to the user'
     )
     INCLUDE_TRACEBACKS: bool = Field(
         False,
         description='If tracebacks should be included where relevant in API '
-                    'responses. Do not enable for untrusted clients!',
+                    'responses. Do not enable for untrusted clients!'
     )
     PROMETHEUS_METRICS_PORT: int = Field(
         13001,
-        description='where to expose internal '
-                    'metrics. Do not allow '
-                    'access from untrusted '
-                    'clients!',
+        description='Where to expose internal metrics. Do not allow '
+                    'access from untrusted clients!'
     )
     AUTH_SECRET_SEED: SecretStr = Field(
         'foo', description='A random string to seed auth secrets with'
@@ -69,53 +67,61 @@ class SFConfig(SFConfigBase):
             '--log-syslog-prefix sf --timeout %(timeout)s --name "%(name)s" '
             'shakenfist.external_api.app:app'
         ),
-        description='The gunicorn command line to use',
+        description='The gunicorn command line to use'
     )
 
     # Scheduler Options
     SCHEDULER_CACHE_TIMEOUT: int = Field(
-        5, description='how long the scheduler should cache things for'
+        5, description='How long the scheduler should cache things for'
     )
     CPU_OVERCOMMIT_RATIO: float = Field(
-        16, description='how many vCPUS per real CPU'
+        16, description='How many vCPUS per real CPU'
     )
     RAM_OVERCOMMIT_RATIO: float = Field(
         1.5,
-        description='how much vRAM per real unit of RAM, that is if Kernel '
+        description='How much vRAM per real unit of RAM, that is if Kernel '
                     'Shared Memory (KSM) is enabled, how much to overcommit '
-                    'memory because of shared pages.',
+                    'memory because of shared pages.'
     )
     RAM_SYSTEM_RESERVATION: float = Field(
-        5.0, description='how much RAM is reserved for the OS'
+        5.0, description='How much RAM is reserved for the OS'
     )
 
     # Network Options
     FLOATING_NETWORK: str = Field(
         '192.168.20.0/24',
         description='Network block used for NAT egress from VMs and floating '
-                    'IPs',
+                    'IPs'
     )
     NETWORK_NODE_IP: str = Field(
         default_factory=get_node_ip,
         description='IP of the node which will egress all traffic',
     )
+    DNS_SERVER: str = Field(
+        '8.8.8.8',
+        description='The DNS server to pass to instances via DHCP.'
+    )
+    MAX_HYPERVISOR_MTU: int = Field(
+        8000,
+        description='Maximum network MTU our hypervisors can safely set.'
+    )
 
     # Database Options
     CLEANER_DELAY: int = Field(
         3600,
         description='How long to wait before removing old data from the '
-                    'database',
+                    'database'
     )
     NODE_CHECKIN_MAXIMUM: int = Field(
         300,
         description='How long to wait before declaring a node to be offline '
-                    'due to failure to check in',
+                    'due to failure to check in'
     )
 
     # Other options
     GLUSTER_ENABLED: bool = Field(
         False,
-        description='If we are using gluster for shared block storage.',
+        description='If we are using gluster for shared block storage.'
     )
     ZONE: str = Field(
         'shakenfist', description='What nova called an availability zone'
@@ -125,14 +131,14 @@ class SFConfig(SFConfigBase):
             'http://download.cirros-cloud.net/%(vernum)s/'
             'cirros-%(vernum)s-x86_64-disk.img'
         ),
-        description='Default download mirror for Cirros image',
+        description='Default download mirror for Cirros image'
     )
     DOWNLOAD_URL_UBUNTU: AnyHttpUrl = Field(
         (
             'https://cloud-images.ubuntu.com/%(vername)s/current/'
             '%(vername)s-server-cloudimg-amd64.img'
         ),
-        description='Default download mirror for Ubuntu image',
+        description='Default download mirror for Ubuntu image'
     )
 
     #################
@@ -142,13 +148,13 @@ class SFConfig(SFConfigBase):
     DISK_BUS: str = Field(
         'virtio',
         description='The bus to use for disk devices. One of virtio, scsi, '
-                    'usb, ide, etc. See libvirt docs for full list of options.',
+                    'usb, ide, etc. See libvirt docs for full list of options.'
     )
     DISK_FORMAT: str = Field(
         'qcow',
         description='The format for disks. Options are qcow (COW layers onto '
                     'of image cache), qcow_flat (just qcow2, no COW), and flat '
-                    '(just raw disk).',
+                    '(just raw disk).'
     )
     NODE_IP: str = Field(
         default_factory=get_node_ip, description='IP of this node'
