@@ -164,21 +164,6 @@ class TaskEncodingETCDtestCase(test_shakenfist.ShakenFistTestCase):
 }'''
         mock_put.assert_called_with(path, encoded, lease=None)
 
-    @mock.patch('etcd3gw.Etcd3Client.put')
-    def test_put_ErrorInstanceTask(self, mock_put):
-        etcd.put('objecttype', 'subtype', 'name',
-                 tasks.ErrorInstanceTask('fake_uuid', 'dunno'))
-
-        path = '/sf/objecttype/subtype/name'
-        encoded = '''{
-    "error_msg": "dunno",
-    "instance_uuid": "fake_uuid",
-    "network": [],
-    "task": "instance_error",
-    "version": 1
-}'''
-        mock_put.assert_called_with(path, encoded, lease=None)
-
     @mock.patch('etcd3gw.Etcd3Client.put')
     def test_put_DeployNetworkTask(self, mock_put):
         etcd.put('objecttype', 'subtype', 'name',
@@ -331,7 +316,7 @@ class TaskDequeueTestCase(test_shakenfist.ShakenFistTestCase):
                         {
                             "network": [],
                             "instance_uuid": "fake_uuid",
-                            "task": "instance_error",
+                            "task": "instance_delete",
                             "version": 1
                         }
                     ]
@@ -348,7 +333,7 @@ class TaskDequeueTestCase(test_shakenfist.ShakenFistTestCase):
         jobname, workitem = etcd.dequeue('node01')
         self.assertEqual('somejob', jobname)
         expected = [
-            tasks.ErrorInstanceTask('fake_uuid'),
+            tasks.DeleteInstanceTask('fake_uuid'),
         ]
         self.assertCountEqual(expected, workitem['tasks'])
         self.assertSequenceEqual(expected, workitem['tasks'])
@@ -369,7 +354,7 @@ class TaskDequeueTestCase(test_shakenfist.ShakenFistTestCase):
                         {
                             "network": [],
                             "instance_uuid": "fake_uuid",
-                            "task": "instance_error",
+                            "task": "instance_delete",
                             "version": 1
                         }
                     ]
@@ -388,7 +373,7 @@ class TaskDequeueTestCase(test_shakenfist.ShakenFistTestCase):
         expected = [
             tasks.PreflightInstanceTask('diff_uuid'),
             tasks.StartInstanceTask('fake_uuid'),
-            tasks.ErrorInstanceTask('fake_uuid'),
+            tasks.DeleteInstanceTask('fake_uuid'),
         ]
         self.assertCountEqual(expected, workitem['tasks'])
         self.assertSequenceEqual(expected, workitem['tasks'])
@@ -458,25 +443,25 @@ class GeneralETCDtestCase(test_shakenfist.ShakenFistTestCase):
 
     @mock.patch('etcd3gw.Etcd3Client.get_prefix',
                 return_value=[
-                     ('''{"checksum": "ed44b9745b8d62bcbbc180b5f36c24bb",
+                    ('''{"checksum": "ed44b9745b8d62bcbbc180b5f36c24bb",
                         "file_version": 1,
                         "size": "359464960",
                         "version": 1
                         }''',
-                      {'key': b'/sf/image/095fdd2b66625412aa/sf-2',
-                       'create_revision': '198335947',
-                       'mod_revision': '198335947',
-                       'version': '1'}),
-                     ('''{"checksum": null,
+                     {'key': b'/sf/image/095fdd2b66625412aa/sf-2',
+                      'create_revision': '198335947',
+                      'mod_revision': '198335947',
+                      'version': '1'}),
+                    ('''{"checksum": null,
                         "file_version": 1,
                         "size": "16338944",
                         "version": 1
                         }''',
-                      {'key': b'/sf/image/aca41cefa18b052074e092/sf-2',
-                       'create_revision': '200780292',
-                       'mod_revision': '200780292',
-                       'version': '1'
-                       })])
+                     {'key': b'/sf/image/aca41cefa18b052074e092/sf-2',
+                      'create_revision': '200780292',
+                      'mod_revision': '200780292',
+                      'version': '1'
+                      })])
     def test_get_all_dict(self, mock_get_prefix):
         data = etcd.get_all_dict('objecttype', 'subtype')
         self.assertDictEqual({
